CachingCustomHandlerState

Struct CachingCustomHandlerState 

pub struct CachingCustomHandlerState<ExecC, QueryC> { /* private fields */ }
Internal state of CachingCustomHandler wrapping internal mutability so it is not exposed to user. Those have to be shared internal state, as after mock is passed to app it is not possible to access mock internals which are not exposed by API.

Implementations

Source

impl<ExecC, QueryC> CachingCustomHandlerState<ExecC, QueryC>

pub fn new() -> Self

Creates a default value for this type.

Source

impl<ExecC, QueryC> CachingCustomHandlerState<ExecC, QueryC>

pub fn execs(&self) -> impl Deref<Target = [ExecC]> + '_

pub fn queries(&self) -> impl Deref<Target = [QueryC]> + '_

pub fn reset(&self)